==> transmission-1.52.tar.bz2: transmission-1.52/macosx/ProgressGradients.h <==
/******************************************************************************
 * $Id: ProgressGradients.h 6995 2008-10-31 00:13:50Z livings124 $
 * 
 * Copyright (c) 2007-2008 Transmission authors and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************/

@class CTGradient;

@interface ProgressGradients : NSObject

+ (CTGradient *) progressGradientForRed: (CGFloat) redComponent green: (CGFloat) greenComponent blue: (CGFloat) blueComponent;

+ (CTGradient *) progressWhiteGradient;
+ (CTGradient *) progressGrayGradient;
+ (CTGradient *) progressLightGrayGradient;
+ (CTGradient *) progressBlueGradient;
+ (CTGradient *) progressDarkBlueGradient;
+ (CTGradient *) progressGreenGradient;
+ (CTGradient *) progressLightGreenGradient;
+ (CTGradient *) progressDarkGreenGradient;
+ (CTGradient *) progressRedGradient;
+ (CTGradient *) progressYellowGradient;

@end

==> transmission_1.92.orig.tar.bz2: transmission-1.92/macosx/ProgressGradients.h <==
/******************************************************************************
 * $Id: ProgressGradients.h 9844 2010-01-01 21:12:04Z livings124 $
 * 
 * Copyright (c) 2007-2010 Transmission authors and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************/

@interface ProgressGradients : NSObject

+ (NSGradient *) progressGradientForRed: (CGFloat) redComponent green: (CGFloat) greenComponent blue: (CGFloat) blueComponent;

+ (NSGradient *) progressWhiteGradient;
+ (NSGradient *) progressGrayGradient;
+ (NSGradient *) progressLightGrayGradient;
+ (NSGradient *) progressBlueGradient;
+ (NSGradient *) progressDarkBlueGradient;
+ (NSGradient *) progressGreenGradient;
+ (NSGradient *) progressLightGreenGradient;
+ (NSGradient *) progressDarkGreenGradient;
+ (NSGradient *) progressRedGradient;
+ (NSGradient *) progressYellowGradient;

@end
